@@ -66,7 +66,7 @@ impl LedgerEthereum {
         &self,
         derivation: &DerivationType,
     ) -> Result<Address, LedgerError> {
-        let data = APDUData::new(&Self::path_to_bytes(&derivation));
+        let data = APDUData::new(&Self::path_to_bytes(derivation));
         let transport = self.transport.lock().await;
         Self::get_address_with_path_transport(&transport, derivation).await
     }
@@ -75,7 +75,7 @@ impl LedgerEthereum {
         transport: &Ledger,
         derivation: &DerivationType,
     ) -> Result<Address, LedgerError> {
-        let data = APDUData::new(&Self::path_to_bytes(&derivation));
+        let data = APDUData::new(&Self::path_to_bytes(derivation));
 
         let command = APDUCommand {
             ins: INS::GET_PUBLIC_KEY as u8,
@@ -137,7 +137,7 @@ impl LedgerEthereum {
     }
 
     // Helper function for signing either transaction data or personal messages
-    async fn sign_payload(
+    pub async fn sign_payload(
         &self,
         command: INS,
         mut payload: Vec<u8>,
