@@ -4,7 +4,9 @@ pub mod types;
 use crate::Signer;
 use app::LedgerEthereum;
 use async_trait::async_trait;
-use ethers_core::types::{transaction::eip2718::TypedTransaction, Address, Signature};
+use ethers_core::types::{
+    transaction::eip2718::TypedTransaction, transaction::eip712::Eip712, Address, Signature,
+};
 use types::LedgerError;
 
 #[cfg_attr(target_arch = "wasm32", async_trait(?Send))]
@@ -25,6 +27,19 @@ impl Signer for LedgerEthereum {
         self.sign_tx(message).await
     }
 
+    async fn sign_typed_data<T: Eip712 + Send + Sync>(
+        &self,
+        payload: T,
+    ) -> Result<Signature, Self::Error> {
+        let hash = payload
+            .encode_eip712()
+            .map_err(|e| Self::Error::Eip712Error(e.to_string()))?;
+
+        let sig = self.sign_message(hash).await?;
+
+        Ok(sig)
+    }
+
     /// Returns the signer's Ethereum Address
     fn address(&self) -> Address {
         self.address
